import {
  BeforeApplicationShutdown,
  Injectable,
  OnApplicationShutdown,
  OnModuleInit,
  Query,
} from '@nestjs/common';
import * as config from '../config.js';
import { Control, Strip } from 'voicemeeter-remote-library/dist';
import { VoicemeeterType } from 'voicemeeter-remote-library/dist/VMR/Control';

export enum IOType {
  STRIP,
  BUS,
}

@Injectable()
export class AppService implements OnModuleInit {
  private control = new Control(config.dllPath, config.headerPath);
  private strips: Strip[];
  // private buses: Bus[];
  async onModuleInit() {
    await this.control.initialize();
    this.control.login();
    this.strips = [...Array(this.getAvailableIOs().strips.total).keys()].map(
      (id) => new Strip(this.control, id),
    );
  }

  getType() {
    return {
      typeId: this.control.voicemeeterType,
      type: VoicemeeterType[this.control.voicemeeterType],
    };
  }
  getAvailableIOs() {
    return {
      buses: this.control.availableBuses,
      strips: this.control.availableStrips,
    };
  }

  getGain(IOType: IOType, id: number) {
    return this.strips[id].Gain;
  }

  setGain(IOType: IOType, id: number, gain: number) {
    return (this.strips[id].Gain = gain);
  }
}
