import {
  Body,
  Controller,
  Get,
  Header,
  HostParam,
  HttpException,
  HttpStatus,
  Param,
  Patch,
  Post,
  Query,
} from '@nestjs/common';
import { AppService, IOType } from './app.service';

@Controller('/strip/:stripId')
export class StripController {
  constructor(private readonly appService: AppService) {}
  @Get('/gain')
  getGain(@Param('stripId') stripId: string) {
    return { gain: this.appService.getGain(IOType.STRIP, +stripId) };
  }
  @Patch('/gain')
  setGain(
    @Param('stripId') stripId: string,
    @Body() { gain }: { gain: number },
  ) {
    if (gain === undefined)
      throw new HttpException(
        'Gain parameter not specified',
        HttpStatus.BAD_REQUEST,
      );
    if (typeof gain !== 'number' || isNaN(gain))
      throw new HttpException(
        'Invalid gain parameter type. Must be a number',
        HttpStatus.BAD_REQUEST,
      );
    return { gain: this.appService.setGain(IOType.STRIP, +stripId, gain) };
  }
}
